@@ -2,30 +2,29 @@ use strict;
 use warnings;
 package Juno::Check::FPing;
 {
-  $Juno::Check::FPing::VERSION = '0.006';
+  $Juno::Check::FPing::VERSION = '0.007';
 }
 # ABSTRACT: An FPing check for Juno
 
 use Carp;
 use AnyEvent::Util 'fork_call';
-use Any::Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw<Int>;
 use namespace::autoclean;
 
 extends 'Juno::Check::RawCommand';
 
 has count => (
     is      => 'ro',
-    isa     => 'Int',
-    default => 3,
+    isa     => Int,
+    default => sub {3},
 );
 
-has '+cmd' => (
-    default => sub {
-        my $self  = shift;
-        my $count = $self->count;
-        return "fping -A -q -c $count \%h";
-    },
-);
+sub _build_cmd {
+    my $self  = shift;
+    my $count = $self->count;
+    return "fping -A -q -c $count \%h";
+}
 
 sub analyze_ping_result {
     my $self   = shift;
@@ -54,8 +53,6 @@ sub analyze_ping_result {
     return 0;
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 
@@ -68,7 +65,7 @@ Juno::Check::FPing - An FPing check for Juno
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 DESCRIPTION
 
