@@ -2,12 +2,14 @@ use strict;
 use warnings;
 package Juno::Check::SNMP;
 {
-  $Juno::Check::SNMP::VERSION = '0.006';
+  $Juno::Check::SNMP::VERSION = '0.007';
 }
 # ABSTRACT: an SNMP check for Juno
 
 use Carp;
-use Any::Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw<Str Int>;
+use Sub::Quote 'quote_sub';
 use namespace::autoclean;
 
 with 'Juno::Role::Check';
@@ -26,32 +28,35 @@ BEGIN {
 
 has hostname => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1,
 );
 
 has community => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1
 );
 
 has version => (
     is       => 'ro',
-    isa      => 'Int',
+    isa      => Int,
     required => 1
 );
 
 has oid => (
     is       => 'ro',
-    isa      => 'Str',
+    isa      => Str,
     required => 1
 );
 
 has session => (
-    is         => 'ro',
-    isa        => 'Net::SNMP',
-    lazy_build => 1
+    is  => 'lazy',
+    isa => quote_sub(q{
+        use Safe::Isa;
+        $_[0]->$_isa('Net::SNMP')
+            or die "$_[0] must be Net::SNMP object";
+    }),
 );
 
 sub _build_session {
@@ -84,8 +89,6 @@ sub check {
     );
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
@@ -97,7 +100,7 @@ Juno::Check::SNMP - an SNMP check for Juno
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 AUTHORS
 
